History
=======

0.0.2 (6/7/2013)
----------------

- Added requirements.txt for Testing Packages.
- Included License.
- PEP8 Compliance (and Docstrings).
- setup.py now pushes package data.
- Updated TravisCI (Comprehensive tests of multiple versions of Flask).

0.0.1 (20/12/2012)
------------------

- Conception
- Initial Commit of Package to GitHub.